==> GNUMail-1.0.3.tar.gz: GNUMail/GNUMail.h <==
/*
**  GNUMail.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#import <AppKit/AppKit.h>

@class AddressBookController;
@class EditWindowController;
@class Message;
@class URLName;

@interface GNUMail : NSObject
{
  // Outlets
  IBOutlet NSMenu *compose;
  IBOutlet NSMenu *drafts;
  IBOutlet NSMenu *edit;
  IBOutlet NSMenu *filters;
  IBOutlet NSMenu *find;
  IBOutlet NSMenu *format;
  IBOutlet NSMenu *incomingMailServers;
  IBOutlet NSMenu *info;
  IBOutlet NSMenu *mailbox;
  IBOutlet NSMenu *menu;
  IBOutlet NSMenu *message;
  IBOutlet NSMenu *print;
  IBOutlet NSMenu *saveAttachment;
  IBOutlet NSMenu *sendToAddressBook;
  IBOutlet NSMenu *services;
  IBOutlet NSMenu *sorting;
  IBOutlet NSMenu *textEncodings;
  IBOutlet NSMenu *windows;
  
  IBOutlet NSMenuItem *deleteOrUndelete;
  IBOutlet NSMenuItem *markAsReadOrUnread;
  IBOutlet NSMenuItem *showAllHeaders;
  IBOutlet NSMenuItem *showOrHideDeleted;
  IBOutlet NSMenuItem *showOrHideRead;
  IBOutlet NSMenuItem *showOrHideStatusBar;
  IBOutlet NSMenuItem *enterSelection;
  IBOutlet NSMenuItem *saveInDrafts;
  IBOutlet NSMenuItem *showRawSource;

  // Other ivars
  Message *messageUsingTextEncoding;
  BOOL lastCopyOpWasSuccessful;
}

- (id) init;

//
// action methods
//
- (IBAction) applyManualFilter: (id) sender;

- (IBAction) bounceMessage: (id) sender;

- (IBAction) changeTextEncoding: (id) sender;

- (IBAction) checkForUpdates: (id) sender;

- (IBAction) close: (id) sender;

- (IBAction) compactMailbox: (id) sender;

- (IBAction) composeMessage: (id) sender;

- (IBAction) copy: (id) sender;
- (IBAction) cut: (id) sender;

- (IBAction) deleteOrUndeleteMessage: (id) sender;

- (IBAction) enterSelectionInFindPanel: (id) sender;

- (IBAction) findNext: (id) sender;
- (IBAction) findPrevious: (id) sender;

- (IBAction) forwardMessage: (id) sender;
- (IBAction) getNewMessages: (id) sender;

- (IBAction) markMessageAsReadOrUnread: (id) sender;

- (IBAction) paste: (id) sender;

- (IBAction) print: (id) sender;

- (IBAction) replyAllMessage: (id) sender;
- (IBAction) replyMessage: (id) sender;

- (IBAction) selectAllMessages: (id) sender;

- (IBAction) restoreDraft: (id) sender;

- (IBAction) saveAllAttachments: (id) sender;
- (IBAction) saveAttachment: (id) sender;
- (IBAction) saveInDrafts: (id) sender;
- (IBAction) saveTextFromMessage: (id) sender;

- (IBAction) sortByNumber: (id) sender;
- (IBAction) sortByDate: (id) sender;
- (IBAction) sortByName: (id) sender;
- (IBAction) sortBySubject: (id) sender;
- (IBAction) sortBySize: (id) sender;

#ifdef MACOSX
- (IBAction) showAboutPanel: (id) sender;
#endif
- (IBAction) showAddressBook: (id) sender;
- (IBAction) showAllHeaders: (id) sender;
- (IBAction) showConsoleWindow: (id) sender;
- (IBAction) showFindWindow: (id) sender;
- (IBAction) showMailboxManager: (id) sender;

- (IBAction) showOrHideDeletedMessages: (id) sender;
- (IBAction) showOrHideReadMessages: (id) sender;
- (IBAction) showOrHideStatusBarForMailWindow: (id) sender;

- (IBAction) showPreferencesWindow: (id) sender;
- (IBAction) showRAWSource: (id) sender;


//
// delegate methods
//
- (BOOL) applicationShouldTerminate: (NSApplication *) theSender;

- (void) applicationWillFinishLaunching: (NSNotification *) theNotification;

- (void) applicationDidFinishLaunching: (NSNotification *) theNotification;


//
// methods invoked by notifications
//
- (void) selectionInTextViewHasChanged: (id) sender;

- (void) selectionOfMessageHasChanged: (id) sender;


//
// access / mutation methods
//
+ (NSArray *) allBundles;

+ (NSArray *) allMailWindows;

+ (NSString *) currentWorkingPath;
+ (void) setCurrentWorkingPath: (NSString *) thePath;

+ (id) lastAddressTakerWindowOnTop;
+ (void) setLastAddressTakerWindowOnTop: (id) aWindow;

+ (id) lastMailWindowOnTop;
+ (void) setLastMailWindowOnTop: (id) aWindow;

- (NSMenu *) saveAttachmentMenu;

- (void) setEnableSaveInDraftsMenuItem: (BOOL) aBOOL;

- (void) setShowRawSourceMenuItem: (BOOL) aBool;

- (NSMenuItem *) showAllHeadersMenuItem;

//
// other methods
// 
- (void) addItemToMenuFromTextAttachment: (NSTextAttachment *) theTextAttachment;

+ (void) addMailWindow: (id) theMailWindow;

- (void) addToAddressBook: (id) sender;

- (void) loadBundles;

- (void) removeAllItemsFromMenu: (NSMenu *) theMenu;

+ (void) removeMailWindow: (id) theMailWindow;

- (void) showFoldersToOpen;

- (void) updateFilterMenuItems: (id) sender;

- (void) updateGetNewMailMenuItems: (id) sender;

- (void) updateMenuItemsForMessage: (Message *) theMessage;

- (void) updateShowOrHideDeletedMenuItem: (BOOL) aBOOL;
- (void) updateShowOrHideReadMenuItem: (BOOL) aBOOL;

- (void) updateTextEncodingsMenu: (id) sender;


//
// services methods
//
- (void) newMessageWithContent: (NSPasteboard *) pboard
	              userData: (NSString *) userData
                         error: (NSString **) error;

- (void) newMessageWithRecipient: (NSPasteboard *) pboard
	                userData: (NSString *) userData
                           error: (NSString **) error;

@end


//
// Private methods
//
@interface GNUMail (Private)

- (Message *) _messageFromLocalDraftsFolderUsingURLName: (URLName *) theURLName;

- (Message *) _messageFromIMAPDraftsFolderUsingURLName: (URLName *) theURLName;


@end

//
// 
//
@interface ExtendedMenuItem : NSMenuItem
{
  NSTextAttachment *textAttachment;
}

- (NSTextAttachment *) textAttachment;
- (void) setTextAttachment: (NSTextAttachment *) theTextAttachment;

@end

==> GNUMail-1.2.0pre1.tar.gz: GNUMail/GNUMail.h <==
/*
**  GNUMail.h
**
**  Copyright (c) 2001-2004
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_GNUMail
#define _GNUMail_H_GNUMail

#import <AppKit/AppKit.h>

@class AddressBookController;
@class CWMessage;
@class CWURLName;
@class EditWindowController;
@class MessageComposition;

@interface GNUMail : NSObject
{
  // Outlets
  IBOutlet NSMenu *drafts;
#ifdef MACOSX
  IBOutlet NSMenu *dock;
#endif
  IBOutlet NSMenu *columns;
  IBOutlet NSMenu *edit;
  IBOutlet NSMenu *filters;
  IBOutlet NSMenu *find;
  IBOutlet NSMenu *incomingMailServers;
  IBOutlet NSMenu *info;
  IBOutlet NSMenu *mailbox;
  IBOutlet NSMenu *menu;
  IBOutlet NSMenu *message;
  IBOutlet NSMenu *save;
  IBOutlet NSMenu *services;
  IBOutlet NSMenu *sorting;
  IBOutlet NSMenu *textEncodings;
  IBOutlet NSMenu *view;
  IBOutlet NSMenu *windows;
  
  IBOutlet NSMenuItem *create;
  IBOutlet NSMenuItem *delete;
  IBOutlet NSMenuItem *deleteOrUndelete;
  IBOutlet NSMenuItem *deliver;
  IBOutlet NSMenuItem *markAsFlaggedOrUnflagged;
  IBOutlet NSMenuItem *markAsReadOrUnread;
  IBOutlet NSMenuItem *showAllHeaders;
  IBOutlet NSMenuItem *showOrHideDeleted;
  IBOutlet NSMenuItem *showOrHideRead;
  IBOutlet NSMenuItem *enterSelection;
  IBOutlet NSMenuItem *rename;
  IBOutlet NSMenuItem *saveInDrafts;
  IBOutlet NSMenuItem *selectAllMessagesInThread;
  IBOutlet NSMenuItem *showRawSource;
  IBOutlet NSMenuItem *threadOrUnthreadMessages;

  //
  // For scripting on Mac OS X. Simple instance variable for to-many relationships.
  //
#ifdef MACOSX
  NSMutableArray *_messageCompositions;
#endif
}

- (id) init;

//
// action methods
//
- (IBAction) applyManualFilter: (id) sender;

- (IBAction) changeTextEncoding: (id) sender;

- (IBAction) checkForUpdates: (id) sender;

- (IBAction) close: (id) sender;

- (IBAction) compactMailbox: (id) sender;

- (IBAction) composeMessage: (id) sender;

- (IBAction) copy: (id) sender;
- (IBAction) cut: (id) sender;

- (IBAction) deleteOrUndeleteMessage: (id) sender;

- (IBAction) enterSelectionInFindPanel: (id) sender;

- (IBAction) findNext: (id) sender;
- (IBAction) findPrevious: (id) sender;

- (IBAction) forwardMessage: (id) sender;
- (IBAction) getNewMessages: (id) sender;

- (IBAction) importMailboxes: (id) sender;

- (IBAction) markMessageAsFlaggedOrUnflagged: (id) sender;
- (IBAction) markMessageAsReadOrUnread: (id) sender;

- (IBAction) nextUnreadMessage: (id) sender;

- (IBAction) newViewerWindow: (id) sender;

- (IBAction) paste: (id) sender;

- (IBAction) previousUnreadMessage: (id) sender;

- (IBAction) printMessage: (id) sender;

- (IBAction) redirectMessage: (id) sender;

- (IBAction) replyToMessage: (id) sender;

- (IBAction) restoreDraft: (id) sender;

- (IBAction) saveAllAttachments: (id) sender;
- (IBAction) saveAttachment: (id) sender;
- (IBAction) saveInDrafts: (id) sender;
- (IBAction) saveTextFromMessage: (id) sender;

- (IBAction) selectAllMessagesInThread: (id) sender;

- (IBAction) sortByNumber: (id) sender;
- (IBAction) sortByDate: (id) sender;
- (IBAction) sortByName: (id) sender;
- (IBAction) sortBySubject: (id) sender;
- (IBAction) sortBySize: (id) sender;

- (IBAction) showAboutPanel: (id) sender;
- (IBAction) showAddressBook: (id) sender;
- (IBAction) showAllHeaders: (id) sender;
- (IBAction) showConsoleWindow: (id) sender;
- (IBAction) showFindWindow: (id) sender;
- (IBAction) showMailboxInspectorPanel: (id) sender;
- (IBAction) showMailboxManager: (id) sender;

- (IBAction) showOrHideDeletedMessages: (id) sender;
- (IBAction) showOrHideReadMessages: (id) sender;
- (IBAction) showOrHideTableColumns: (id) sender;

- (IBAction) showPreferencesWindow: (id) sender;
- (IBAction) showRawSource: (id) sender;

- (IBAction) threadOrUnthreadMessages: (id) sender;


//
// methods invoked by notifications
//
- (void) selectionInTextViewHasChanged: (id) sender;
- (void) selectionOfMessageHasChanged: (id) sender;


//
// access / mutation methods
//
+ (NSArray *) allBundles;

+ (NSArray *) allMailWindows;

+ (NSString *) currentWorkingPath;
+ (void) setCurrentWorkingPath: (NSString *) thePath;

+ (id) lastAddressTakerWindowOnTop;
+ (void) setLastAddressTakerWindowOnTop: (id) aWindow;

+ (id) lastMailWindowOnTop;
+ (void) setLastMailWindowOnTop: (id) aWindow;

- (NSMenu *) saveMenu;
- (NSMenuItem *) deliverMenuItem;

- (void) setEnableSaveInDraftsMenuItem: (BOOL) aBOOL;

- (void) setShowRawSourceMenuItem: (BOOL) aBOOL;

- (NSMenuItem *) showAllHeadersMenuItem;

//
// other methods
// 
- (void) addItemToMenuFromTextAttachment: (NSTextAttachment *) theTextAttachment;

+ (void) addEditWindow: (id) theEditWindow;
+ (void) addMailWindow: (id) theMailWindow;

- (void) newMessageWithRecipient: (NSString *) aString;

+ (void) removeEditWindow: (id) theEditWindow;
+ (void) removeMailWindow: (id) theMailWindow;

- (void) updateMenuItemsForMessage: (CWMessage *) theMessage;

- (void) updateShowOrHideDeletedMenuItem: (BOOL) aBOOL;
- (void) updateShowOrHideReadMenuItem: (BOOL) aBOOL;

- (void) updateThreadOrUnthreadMenuItem: (BOOL) aBOOL;

@end


//
// Experimental code used for Mac OS X scripting support.
//
#ifdef MACOSX

@interface GNUMail (KeyValueCoding)

- (BOOL)application:(NSApplication *)sender delegateHandlesKey:(NSString *)key;
- (NSMutableArray*)messageCompositions;
- (void)setMessageCompositions: (NSMutableArray*)messageCompositions;
- (void) addInMessageCompositions: (MessageComposition *)object;
- (void) insertInMessageCompositions: (MessageComposition *) object;
- (void) insertInMessageCompositions: (MessageComposition *) object atIndex: (unsigned) index;
- (void) replaceInMessageCompositions: (MessageComposition *) object atIndex: (unsigned) index;
- (void) removeFromMessageCompositionsAtIndex: (unsigned) index;
- (id) valueInMessageCompositionsAtIndex: (unsigned) index;

@end
#endif

#endif // _GNUMail_H_GNUMail
